@@ -43,12 +43,13 @@ from ..custom_types import (
     WhoAmI,
     UserEmailAndId,
     EmailDomainAndOrgId,
-    CategorySummary,
-    CategorySummaries,
+    MatGroupSummary,
+    MatGroupSummaries,
     EvaluationSummary,
     EvaluationSummaries,
+    EmptyEvaluation,
 )
-from ..eid import get_org_eid, get_user_eid
+from ..eid import get_org_eid, get_user_eid, get_eval_eid
 from ..http_return import (
     http_200_json,
     http_400_json,
@@ -615,37 +616,71 @@ class Auth:
                 reasons=[f"{ex}"],
             )
 
-    def put_category_summaries(
+    def put_mat_group_summaries(
         self, user_id: str
     ) -> Union[PutObjectOutputTypeDef, CustomError]:
         try:
-            error_msg = f"Could not put category summary: {user_id}"
-            cats = [
-                CategorySummary(
-                    categoryId="cat-xbyckrvqbjbpq2aoboa7o4zb7y",
-                    categoryName="360º Review",
-                    description="A 360-degree feedback is ...",
+            error_msg = f"Could not put mat group summary: {user_id}"
+            mgs = [
+                MatGroupSummary(
+                    matGroupId="mg-zyae7hws2kdwjteuukboxw4r5a",
+                    matGroupName="Group 1",
+                    description="Tests flexibility, knowledge and experience of employees",
                     hasUnfilled=False,
                 ),
-                CategorySummary(
-                    categoryId="cat-pj4ofwyimnapusd3toqoetb2ou",
-                    categoryName="Employee Satisfaction",
-                    description="How satisifed the employees are",
+                MatGroupSummary(
+                    matGroupId="mg-i6xu3cz5yznfp6twhlkwoixqpe",
+                    matGroupName="Favorites",
+                    description="Favorite drinks, foods, series, games, and series",
                     hasUnfilled=True,
                 ),
-                CategorySummary(
-                    categoryId="cat-h54wcy7l7fdrrxq425mcmvoaci",
-                    categoryName="Other",
-                    description="Miscellaneous",
-                    hasUnfilled=False,
-                ),
             ]
-            category_summaries = CategorySummaries.parse_obj(cats)
+            mat_group_summaries = MatGroupSummaries.parse_obj(mgs)
             s3_response = s3_put_object_bytes(
                 Auth.clients.s3_client,
                 self.config.s3_bucket,
-                f"api/index/evals/{user_id}/category-summaries.json",
-                category_summaries.json().encode("utf-8"),
+                f"api/index/evals/{user_id}/mat-group-summaries.json",
+                mat_group_summaries.json().encode("utf-8"),
+            )
+
+            if isinstance(s3_response, HttpError):
+                LOG.error(s3_response)
+                return CustomError(
+                    message=s3_response.error.message,
+                    reasons=s3_response.error.reasons,
+                )
+            else:
+                return s3_response
+
+        except Exception as ex:
+            LOG.error(error_msg)
+            return CustomError(
+                message=error_msg,
+                reasons=[f"{ex}"],
+            )
+
+    def put_favorite_drinks_eval_summary(
+        self, user_id: str, eval_id: str
+    ) -> Union[PutObjectOutputTypeDef, CustomError]:
+        try:
+            error_msg = f"Could not put favorite drinks eval summary: {user_id}"
+            favorite_drinks_eval = [
+                EvaluationSummary(
+                    evaluationId=eval_id,
+                    evaluationName="Favorite Drinks",
+                    matId="mat-7wby5o6exxce3md5yczyv26y5m",
+                    status="unfilled",
+                    createDate="2023-01-11",
+                    dueDate="2023-09-30",
+                    targetGroup="All",
+                )
+            ]
+            evaluation_summaries = EvaluationSummaries.parse_obj(favorite_drinks_eval)
+            s3_response = s3_put_object_bytes(
+                Auth.clients.s3_client,
+                self.config.s3_bucket,
+                f"api/index/evals/{user_id}/mg-i6xu3cz5yznfp6twhlkwoixqpe/unfilled.json",
+                evaluation_summaries.json().encode("utf-8"),
             )
 
             if isinstance(s3_response, HttpError):
@@ -665,27 +700,23 @@ class Auth:
             )
 
     def put_favorite_drinks_eval(
-        self, user_id: str
+        self, eval_id: str
     ) -> Union[PutObjectOutputTypeDef, CustomError]:
         try:
-            error_msg = f"Could not put evaluation starter pack: {user_id}"
-            favorite_drinks_eval = [
-                EvaluationSummary(
-                    evaluationId="eva-pze4xhqb5rbmedhqrmgd2l7i6m",
-                    evaluationName="Favorite Drinks",
-                    matId="mat-7wby5o6exxce3md5yczyv26y5m",
-                    status="unfilled",
-                    createDate="2023-01-11",
-                    dueDate="2023-09-30",
-                    targetGroup="All",
-                )
-            ]
-            evaluation_summaries = EvaluationSummaries.parse_obj(favorite_drinks_eval)
+            error_msg = f"Could not put favorite drinks eval: {eval_id}"
+
+            favorite_drinks_eval = EmptyEvaluation(
+                evaluationId=eval_id,
+                evaluationName="Favorite Drinks",
+                matId="mat-7wby5o6exxce3md5yczyv26y5m",
+                matGroupId="mg-i6xu3cz5yznfp6twhlkwoixqpe",
+            )
+
             s3_response = s3_put_object_bytes(
                 Auth.clients.s3_client,
                 self.config.s3_bucket,
-                f"api/index/evals/{user_id}/cat-pj4ofwyimnapusd3toqoetb2ou/unfilled.json",
-                evaluation_summaries.json().encode("utf-8"),
+                f"api/evals/mat-7wby5o6exxce3md5yczyv26y5m/unfilled/{eval_id}.json",
+                favorite_drinks_eval.json().encode("utf-8"),
             )
 
             if isinstance(s3_response, HttpError):
@@ -710,11 +741,9 @@ class Auth:
             empty_file = EvaluationSummaries(__root__=[])
 
             keys = [
-                f"api/index/evals/{user_id}/cat-pj4ofwyimnapusd3toqoetb2ou/filled.json",
-                f"api/index/evals/{user_id}/cat-xbyckrvqbjbpq2aoboa7o4zb7y/filled.json",
-                f"api/index/evals/{user_id}/cat-xbyckrvqbjbpq2aoboa7o4zb7y/unfilled.json",
-                f"api/index/evals/{user_id}/cat-h54wcy7l7fdrrxq425mcmvoaci/filled.json",
-                f"api/index/evals/{user_id}/cat-h54wcy7l7fdrrxq425mcmvoaci/unfilled.json",
+                f"api/index/evals/{user_id}/mg-i6xu3cz5yznfp6twhlkwoixqpe/filled.json",
+                f"api/index/evals/{user_id}/mg-zyae7hws2kdwjteuukboxw4r5a/filled.json",
+                f"api/index/evals/{user_id}/mg-zyae7hws2kdwjteuukboxw4r5a/unfilled.json",
             ]
             bu = self.config.s3_bucket
             cl = Auth.clients.s3_client
@@ -743,16 +772,24 @@ class Auth:
             error_msg = f"Could not create user: {user_id}"
 
             s3_responses = []
+            fav_drinks_eval_id = get_eval_eid()
 
             user_email_and_id_response = self.put_user_email_and_id(
                 email_address, user_id, org_id
             )
             s3_responses.append(user_email_and_id_response)
 
-            category_summaries_response = self.put_category_summaries(user_id)
-            s3_responses.append(category_summaries_response)
+            mat_group_summaries_response = self.put_mat_group_summaries(user_id)
+            s3_responses.append(mat_group_summaries_response)
 
-            favorite_drinks_eval_repsponse = self.put_favorite_drinks_eval(user_id)
+            favorite_drinks_eval_sum_repsponse = self.put_favorite_drinks_eval_summary(
+                user_id, fav_drinks_eval_id
+            )
+            s3_responses.append(favorite_drinks_eval_sum_repsponse)
+
+            favorite_drinks_eval_repsponse = self.put_favorite_drinks_eval(
+                fav_drinks_eval_id
+            )
             s3_responses.append(favorite_drinks_eval_repsponse)
 
             put_empty_evals_response = self.put_empty_eval_summaries(user_id)
